@@ -14,6 +14,18 @@ sub wordlist {
     my $obj = shift;
     my $text = shift;
 
+    ##
+    ## mecab ignores trailing spaces.
+    ##
+    my $removeme = sub {
+	local *_ = shift;
+	return sub { 0 } unless /[ \t]+$/m;
+	my $magic = "95570"."67583";
+	$magic++ while /$magic/;
+	s/[ \t]+\K$/$magic/mg;
+	sub { $_ eq $magic };
+    }->(\$text);
+
     my $eos = "EOS" . "000";
     $eos++ while $text =~ /$eos/;
     my $mecab = [ 'mecab', '--node-format', '%M\\n', '--eos-format', "$eos\\n" ];
@@ -21,6 +33,7 @@ sub wordlist {
     warn $result =~ s/^/MECAB: /mgr if $debug;
     do {
 	map  { $_ eq $eos ? "\n" : $_ }
+	grep { not $removeme->() }
 	grep { length }
 	$result =~ /^(\s*)(\S+)\n/amg;
     };
